@@ -7,7 +7,7 @@ d2 <- function(series, m, d, t, eps.min, neps=100) {
 	eps.max <- diff(range(series))*sqrt(m)
 	res <- .C("d2", series=as.double(series), length=as.integer(length(series)), m=as.integer(m), d=as.integer(d), t=as.integer(t), neps=as.integer(neps), eps.max=as.double(eps.max), eps.min=as.double(eps.min), res=as.double(res), 
 	PACKAGE="tseriesChaos")[["res"]]
-	res <- matrix(res, neps, m)
+	res <- t(matrix(res, m, neps))
 	res <- res[neps:1,]
 	denom <- length(series) - (m-1)*d
 	denom <- (denom-t+1)*(denom-t)/2
@@ -17,7 +17,16 @@ d2 <- function(series, m, d, t, eps.min, neps=100) {
 	eps <- eps[neps:1]
 	res <- cbind(eps, res)
 	colnames(res) <- c("eps",paste("m", 1:m,sep=""))
-	plot(res[,c(1,m+1)], type="l", log="xy", main="Sample correlation integral", xlab=expression(epsilon), ylab=expression(C(epsilon)))
-	for(i in m:2) lines(res[,c(1,i)])
-	invisible(res)
+	class(res) <- "d2"
+	res
+}
+
+plot.d2 <- function(x, ...) {
+	m <- ncol(x)
+	plot(x[,c(1,m)], type="l", log="xy", main="Sample correlation integral", xlab=expression(epsilon), ylab=expression(C(epsilon)))
+	for(i in (m-1):2) lines(x[,c(1,i)])
+}
+
+print.d2 <- function(x, ...) {
+	plot(x)
 }
